@@ -1,15 +1,14 @@
 /*
  * Copyright (C) 2002-2004 Sistina Software, Inc. All rights reserved.
- * Copyright (C) 2004 Red Hat, Inc. All rights reserved.
+ * Copyright (C) 2004-2007 Red Hat, Inc. All rights reserved.
  *
- * This file is part of device-mapper userspace tools.
- * The code is based on LVM2 report function.
+ * This file is part of the device-mapper userspace tools.
  *
  * This copyrighted material is made available to anyone wishing to use,
  * modify, copy, or redistribute it subject to the terms and conditions
- * of the GNU General Public License v.2.
+ * of the GNU Lesser General Public License v.2.1.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
@@ -261,16 +260,16 @@ static void _display_fields(struct dm_report *rh)
 			desc = " ";
 		if (desc != last_desc) {
 			if (*last_desc)
-				log_print(" ");
-			log_print("%s Fields", desc);
-			log_print("%*.*s", (int) strlen(desc) + 7,
-				  (int) strlen(desc) + 7,
-				  "------------------------------------------");
+				log_warn(" ");
+			log_warn("%s Fields", desc);
+			log_warn("%*.*s", (int) strlen(desc) + 7,
+				 (int) strlen(desc) + 7,
+				 "------------------------------------------");
 				  
 		}
 
 		/* FIXME Add line-wrapping at terminal width (or 80 cols) */
-		log_print("  %-*s - %s", (int) id_len, rh->fields[f].id, rh->fields[f].desc);
+		log_warn("  %-*s - %s", (int) id_len, rh->fields[f].id, rh->fields[f].desc);
 		last_desc = desc;
 	}
 }
@@ -445,7 +444,7 @@ static int _parse_options(struct dm_report *rh, const char *format)
 
 		if (!_field_match(rh, ws, (size_t) (we - ws))) {
 			_display_fields(rh);
-			log_print(" ");
+			log_warn(" ");
 			if (strcasecmp(ws, "help") && strcmp(ws, "?"))
 				log_error("Unrecognised field: %.*s",
 					  (int) (we - ws), ws);
